%define upstream_name Devel-Confess
%define upstream_version 0.009004

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 5

Summary:    Include stack traces on all warnings and errors
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Devel/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Cwd)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Temp)
BuildRequires: perl(IPC::Open3)
BuildRequires: perl(Safe)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test::More)
BuildArch:  noarch

%description
This module is meant as a debugging aid. It can be used to make a script
complain loudly with stack backtraces when warn()ing or die()ing. Unlike
other similar modules (e.g. Carp::Always), it includes stack traces even
when exception objects are thrown.

The stack traces are generated using Carp, and will look work for all
types of errors. Carp's "carp" and "confess" functions will also be made
to include stack traces.

  # it works for explicit die's and warn's
  $ perl -d:Confess -e 'sub f { die "arghh" }; sub g { f }; g'
  arghh at -e line 1.
          main::f() called at -e line 1
          main::g() called at -e line 1

  # it works for interpreter-thrown failures
  $ perl -d:Confess -w -e 'sub f { $a = shift; @a = @$a };' \
                                            -e 'sub g { f(undef) }; g'
  Use of uninitialized value $a in array dereference at -e line 1.
          main::f(undef) called at -e line 2
          main::g() called at -e line 2

Internally, this is implemented with $SIG{__WARN__} and $SIG{__DIE__}
hooks.

Stack traces are also included if raw non-object references are thrown.

%prep
%autosetup -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Fri Jun 27 2025 umeabot <umeabot> 0.9.4-5.mga10
+ Revision: 2203564
- Mageia 10 Mass Rebuild

* Sun Mar 20 2022 umeabot <umeabot> 0.9.4-4.mga9
+ Revision: 1808760
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.9.4-3.mga8
+ Revision: 1503818
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0.9.4-2.mga7
+ Revision: 1282772
- Mageia 7 Mass Rebuild

* Wed Jul 19 2017 sander85 <sander85> 0.9.4-1.mga7
+ Revision: 1125082
- update to 0.009004

* Sun Jun 19 2016 pterjan <pterjan> 0.8.0-3.mga6
+ Revision: 1025499
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 0.8.0-2.mga6
+ Revision: 968017
- Mageia 6 Mass Rebuild

* Sun Jul 05 2015 sander85 <sander85> 0.8.0-1.mga6
+ Revision: 851066
- imported package perl-Devel-Confess

